var user_id;
var customer_id;

document.addEventListener('DOMContentLoaded', () => {
    initializeCharts();
    fetchUserIdFromSession();

    // Setup event listeners for static and dynamically added dropdown buttons
    document.addEventListener('click', function(event) {
        const target = event.target;
        // Check if the clicked element or its parent is a dropbtn
        const dropBtn = target.closest('.dropbtn');

        if (dropBtn) {
            // Prevent the click event from closing the dropdown immediately
            event.stopPropagation();

            // Find the closest parent that has either 'company-name' or 'user-info' class
            const parentContainer = dropBtn.closest('.company-name, .user-info');

            // Toggle the dropdown content within this container
            const dropdownContent = parentContainer.querySelector('.dropdown-content');
            if (dropdownContent) {
                dropdownContent.classList.toggle('show');
            }
        } else {
            // Clicked outside, close all dropdowns
            closeAllDropdowns();
        }
    });

    // Close dropdowns when clicking outside
    document.body.addEventListener('click', closeAllDropdowns);

    // Setup event listener for the "Risk Assessment" sidebar link
    const riskAssessmentLink = document.querySelector('.sidebar-link[href="#risk-assessment"]');
    if (riskAssessmentLink) {
        riskAssessmentLink.addEventListener('click', function(event) {
            event.preventDefault(); // Prevent the default navigation
            openRAandRTP(); // Call the function when the link is clicked
        });
    }
});

function closeAllDropdowns() {
    document.querySelectorAll('.dropdown-content.show').forEach(dropdownContent => {
        dropdownContent.classList.remove('show');
    });
}


function initializeCharts() {
    const barCtx = document.getElementById('barChart').getContext('2d');
    const pieCtx = document.getElementById('pieChart').getContext('2d');

    const barChart = new Chart(barCtx, {
      type: 'bar',
      data: {
        labels: ['January', 'February', 'March', 'April'],
        datasets: [{
          label: 'Dataset 1',
          data: [50, 60, 70, 80],
          backgroundColor: 'rgba(0, 123, 255, 0.5)'
        }]
      },
      options: {
        scales: {
          y: {
            beginAtZero: true
          }
        }
      }
    });

    const pieChart = new Chart(pieCtx, {
      type: 'pie',
      data: {
        labels: ['Red', 'Blue', 'Yellow'],
        datasets: [{
          data: [300, 50, 100],
          backgroundColor: ['red', 'blue', 'yellow']
        }]
      }
    });
}

function fetchUserIdFromSession() {
    // Make a GET request to a server endpoint that returns the session data
    fetch('/get-user-id', {
        method: 'GET',
        credentials: 'include',
    })
    .then(response => response.json())
    .then(data => {
        // Check if 'user_id' is available in the session data
        if (data.user_id !== undefined) {
            user_id = data.user_id;
            console.log('User ID:', user_id);

            // Fetch user data using 'user_id'
            fetchUserData(user_id);
        } else {
            console.error('User is not authenticated or session data is missing.');
        }
    })
    .catch(error => console.error('Error fetching user session data:', error));
}

function fetchUserData(user_Id) {
    const apiUrl = `/api/user-data/${user_Id}`;

    // Make a GET request to the API endpoint
    fetch(apiUrl)
        .then(response => {
            if (!response.ok) {
                throw new Error('Network response was not ok');
            }
            return response.json();
        })
        .then(data => {
            customer_id = data.customer_id;
            // Creating a UserData object with the response data
            const userData = {
                first_name: data.first_name,
                last_name: data.last_name,
                last_login: data.last_login,
                customer_id: data.customer_id,
            };
            updateUserUI(userData);
            console.log(userData);
            const customerIds = getCustomerIds(data.customer_id);
            console.log('populateCompanyDropdown called with customerIds:', customerIds);
            populateCompanyDropdown(customerIds);
        })
        .catch(error => {
            // Handle errors that occurred during the fetch request
            console.error('Fetch error:', error);
        });
}

function getCustomerIds(customerIdString) {
    // Check if customerIdString is not undefined or null
    if (customerIdString) {
        // Split the string by commas to create an array
        return customerIdString.split(",");
    } else {
        // Return an empty array if customerIdString is undefined or null
        return [];
    }
}

function updateUserUI(userData) {
    // Update the UI with the user data
    document.getElementById('firstName').textContent = userData.first_name;
    document.getElementById('lastName').textContent = userData.last_name;

}

async function populateCompanyDropdown(customerIds) {
    const companyListContainer = document.querySelector('#companyListContainer');
    if (!companyListContainer) {
        console.error('The company list container element was not found.');
        return;
    }

    companyListContainer.innerHTML = ''; // Clear previous content

    if (customerIds.length > 1) {
        const companyDiv = document.createElement('div');
        companyDiv.className = 'company-name';

        const button = document.createElement('button');
        button.className = 'dropbtn';
        button.innerHTML = `Clients <i class="fas fa-chevron-down"></i>`;
        button.addEventListener('click', function() {
            this.nextElementSibling.classList.toggle('show');
        });

        const dropdownContent = document.createElement('div');
        dropdownContent.className = 'dropdown-content';

        companyDiv.appendChild(button);
        companyDiv.appendChild(dropdownContent);
        companyListContainer.appendChild(companyDiv);

        // Fetch and populate for each customerId
        for (const customerId of customerIds) {
            await fetchAndPopulate(customerId, dropdownContent);
        }
    } else if (customerIds.length === 1) {
        // Only one customerId, fetch and display its name directly
        await fetchAndPopulate(customerIds[0], companyListContainer, true);
    }

    // Click outside to close dropdowns
    window.onclick = function(event) {
        if (!event.target.matches('.dropbtn')) {
            var dropdowns = document.getElementsByClassName("dropdown-content");
            for (var i = 0; i < dropdowns.length; i++) {
                var openDropdown = dropdowns[i];
                if (openDropdown.classList.contains('show')) {
                    openDropdown.classList.remove('show');
                }
            }
        }
    };
}


async function fetchAndPopulate(customerId, container, isSingle = false) {
    const apiUrl = `/fetch-customer-projects?customer_id=${customerId}`;
    try {
        const response = await fetch(apiUrl);
        if (!response.ok) {
            throw new Error(`Error fetching projects for customer ID ${customerId}: ${response.statusText}`);
        }
        const data = await response.json();

        if (isSingle) {
            const companyName = data.projects[0]?.customer_name || 'Unknown';
            const companyDiv = document.createElement('div');
            companyDiv.className = 'company-name';

            const button = document.createElement('button');
            button.className = 'dropbtn';
            button.innerHTML = `${companyName} <i class="fas fa-chevron-down"></i>`;
            button.addEventListener('click', function() {
                this.nextElementSibling.classList.toggle('show');
            });

            const dropdownContent = document.createElement('div');
            dropdownContent.className = 'dropdown-content';

            companyDiv.appendChild(button);
            companyDiv.appendChild(dropdownContent);
            container.appendChild(companyDiv);
        } else {
            data.projects.forEach(project => {
                const clientName = project.customer_name || 'Unknown';
                const projectElement = document.createElement('a');
                projectElement.textContent = clientName;
                container.appendChild(projectElement);
            });
        }
    } catch (error) {
        console.error("Fetch error:", error);
    }
}

function openRAandRTP() {
    console.log("customer_id in openRAandRTP: " +customer_id)
    var apiUrl = '/fetch-customer-projects?customer_id=' + encodeURIComponent(customer_id);

    fetch(apiUrl)
    .then(response => response.json())
    .then(data => {
        if (data.projects && data.projects.length === 1) {
            var selectedProject = data.projects[0];
            checkRAandRTPRecord(selectedProject.project_id, selectedProject.project_name);
        } else if (data.projects && data.projects.length > 0) {
            var projectSelectionMessage = 'Please select the project for the RA&RTP:\n';
            data.projects.forEach((project, index) => {
                projectSelectionMessage += (index + 1) + '. ' + project.project_name + ' (ID: ' + project.project_id + ')\n';
            });

            var selectedProjectNumber = prompt(projectSelectionMessage);
            var selectedProjectIndex = parseInt(selectedProjectNumber, 10) - 1;

            if (selectedProjectIndex >= 0 && selectedProjectIndex < data.projects.length) {
                var selectedProject = data.projects[selectedProjectIndex];
                checkRAandRTPRecord(selectedProject.project_id, selectedProject.project_name);
            } else {
                alert('Invalid project number');
            }
        } else {
            alert('No projects found for this customer.');
        }
    })
    .catch(error => {
        console.error('Error fetching projects:', error);
        alert('Error fetching projects');
    });
}

function checkRAandRTPRecord(projectId, projectName) {
    fetch(`/fetch-ra-rtp-data?projectId=${projectId}`)
    .then(response => response.json())
    .then(data => {
        if (!data.id) { // Assuming 'id' is a field indicating a record exists
            var createNewRecord = confirm('No RA&RTP record found for this project. Would you like to create a new RA&RTP record?');
            if (createNewRecord) {
                // Submit the new RA-RTP record
                const raRtpData = {
                    project_id: projectId,
                    project_name: projectName,
                    customer_name: clientname,
                    created_by: userfullname,
                    version_number: 1.0
                };

                fetch('/submit-ra-rtp', {
                    method: 'POST',
                    headers: {'Content-Type': 'application/json'},
                    body: JSON.stringify(raRtpData)
                })
                .then(response => {
                    if (response.ok) {
                        alert('RA-RTP record created successfully.');
                        window.location.href = `/risk-assessment-treatment/${projectId}`; // Redirect to the RA-RTP page
                    } else {
                        throw new Error('Failed to create RA-RTP record.');
                    }
                });
            }
        } else {
            window.location.href = `/risk-assessment-treatment/${projectId}`; // Redirect to the RA-RTP page
        }
    })
    .catch(error => {
        console.error('Error checking RA&RTP record:', error);
        alert('Error checking RA&RTP record');
    });
}

